@@ -5,6 +5,7 @@ __all__ = (
     'NavBarItem',
     'StandardNavBar',
     'TextAreaField',
+    'JsonField',
     'TreeView',
     'StringField',
     'PasswordField',
@@ -15,9 +16,10 @@ __all__ = (
     'StandardField',
     'StandardForm',
     'DTGrid',
-    'HTMLGrid'
+    'HTMLGrid',
+    'ViewOnlyForm',
 )
 
 __author__ = "John Bannister <eudorajab1@gmail.com>"
 __license__ = "MIT"
-__version__ = "0.0.3"
+__version__ = "0.0.5"
